@@ -1,16 +1,38 @@
 #ABSTRACT: NBI Slurm module
 use strict;
 use warnings;
+
 package NBI::Slurm;
-
-$NBI::Slurm::VERSION = '0.2.0';
-
 use NBI::Job;
 use NBI::Opts;
-
-# Export both classes
 use base qw(Exporter);
-our @EXPORT_OK = qw(NBI::Job NBI::Opts);
+our @ISA = qw(Exporter);
+our @EXPORT = qw(Job Opts %FORMAT_STRINGS);
+$NBI::Slurm::VERSION = '0.3.0';
+
+
+
+
+our %FORMAT_STRINGS = (
+ 'account'    => '%a',
+ 'jobid'      => '%A',
+ 'jobname'    => '%j',
+ 'cpus'       => '%C',
+ 'end_time'   => '%E',
+ 'start_time' => '%S',
+ 'total_time' => '%l',
+ 'time_left'  => '%L',
+ 'memory'     => '%m',
+ 'command'    => '%o',
+ 'queue'      => '%P',
+ 'reason'     => '%r',
+ 'status'     => '%T', # short: %t
+ 'workdir'    => '%Z',
+ 'user'       => '%u',
+);
+
+
+
 
 
 1;
@@ -27,7 +49,7 @@ NBI::Slurm - NBI Slurm module
 
 =head1 VERSION
 
-version 0.2.0
+version 0.3.0
 
 =head1 SYNOPSIS
 
